==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/tl.php <==
<?php

return [
    'Names' => [
        'aa' => 'Afar',
        'ab' => 'Abkhazian',
        'ace' => 'Achinese',
        'ach' => 'Acoli',
        'ada' => 'Adangme',
        'ady' => 'Adyghe',
        'af' => 'Afrikaans',
        'agq' => 'Aghem',
        'ain' => 'Ainu',
        'ak' => 'Akan',
        'ale' => 'Aleut',
        'alt' => 'Southern Altai',
        'am' => 'Amharic',
        'an' => 'Aragonese',
        'ann' => 'Obolo',
        'anp' => 'Angika',
        'ar' => 'Arabic',
        'arn' => 'Mapuche',
        'arp' => 'Arapaho',
        'ars' => 'Najdi Arabic',
        'as' => 'Assamese',
        'asa' => 'Asu',
        'ast' => 'Asturian',
        'atj' => 'Atikamekw',
        'av' => 'Avaric',
        'awa' => 'Awadhi',
        'ay' => 'Aymara',
        'az' => 'Azerbaijani',
        'ba' => 'Bashkir',
        'ban' => 'Balinese',
        'bas' => 'Basaa',
        'be' => 'Belarusian',
        'bem' => 'Bemba',
        'bez' => 'Bena',
        'bg' => 'Bulgarian',
        'bgn' => 'Kanlurang Balochi',
        'bho' => 'Bhojpuri',
        'bi' => 'Bislama',
        'bin' => 'Bini',
        'bla' => 'Siksika',
        'bm' => 'Bambara',
        'bn' => 'Bangla',
        'bo' => 'Tibetan',
        'br' => 'Breton',
        'brx' => 'Bodo',
        'bs' => 'Bosnian',
        'bug' => 'Buginese',
        'byn' => 'Blin',
        'ca' => 'Catalan',
        'cay' => 'Cayuga',
        'ccp' => 'Chakma',
        'ce' => 'Chechen',
        'ceb' => 'Cebuano',
        'cgg' => 'Chiga',
        'ch' => 'Chamorro',
        'chk' => 'Chuukese',
        'chm' => 'Mari',
        'cho' => 'Choctaw',
        'chp' => 'Chipewyan',
        'chr' => 'Cherokee',
        'chy' => 'Cheyenne',
        'ckb' => 'Central Kurdish',
        'clc' => 'Chilcotin',
        'co' => 'Corsican',
        'crg' => 'Michif',
        'crj' => 'Southern East Cree',
        'crk' => 'Plains Cree',
        'crl' => 'Northern East Cree',
        'crm' => 'Moose Cree',
        'crr' => 'Carolina Algonquian',
        'crs' => 'Seselwa Creole French',
        'cs' => 'Czech',
        'csw' => 'Latian na Cree',
        'cu' => 'Church Slavic',
        'cv' => 'Chuvash',
        'cy' => 'Welsh',
        'da' => 'Danish',
        'dak' => 'Dakota',
        'dar' => 'Dargwa',
        'dav' => 'Taita',
        'de' => 'German',
        'dgr' => 'Dogrib',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Lower Sorbian',
        'dua' => 'Duala',
        'dv' => 'Divehi',
        'dyo' => 'Jola-Fonyi',
        'dz' => 'Dzongkha',
        'dzg' => 'Dazaga',
        'ebu' => 'Embu',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'eka' => 'Ekajuk',
        'el' => 'Greek',
        'en' => 'Ingles',
        'eo' => 'Esperanto',
        'es' => 'Spanish',
        'et' => 'Estonian',
        'eu' => 'Basque',
        'ewo' => 'Ewondo',
        'fa' => 'Persian',
        'ff' => 'Fulah',
        'fi' => 'Finnish',
        'fil' => 'Filipino',
        'fj' => 'Fijian',
        'fo' => 'Faroese',
        'fon' => 'Fon',
        'fr' => 'French',
        'frc' => 'Cajun French',
        'frr' => 'Hilagang Frisian',
        'fur' => 'Friulian',
        'fy' => 'Kanlurang Frisian',
        'ga' => 'Irish',
        'gaa' => 'Ga',
        'gag' => 'Gagauz',
        'gd' => 'Scottish Gaelic',
        'gez' => 'Geez',
        'gil' => 'Gilbertese',
        'gl' => 'Galician',
        'gn' => 'Guarani',
        'gor' => 'Gorontalo',
        'gsw' => 'Swiss German',
        'gu' => 'Gujarati',
        'guz' => 'Gusii',
        'gv' => 'Manx',
        'gwi' => 'Gwichʼin',
        'ha' => 'Hausa',
        'hai' => 'Haida',
        'haw' => 'Hawaiian',
        'hax' => 'Katimugang Haida',
        'he' => 'Hebrew',
        'hi' => 'Hindi',
        'hil' => 'Hiligaynon',
        'hmn' => 'Hmong',
        'hr' => 'Croatian',
        'hsb' => 'Upper Sorbian',
        'ht' => 'Haitian',
        'hu' => 'Hungarian',
        'hup' => 'Hupa',
        'hur' => 'Halkomelem',
        'hy' => 'Armenian',
        'hz' => 'Herero',
        'ia' => 'Interlingua',
        'iba' => 'Iban',
        'ibb' => 'Ibibio',
        'id' => 'Indonesian',
        'ie' => 'Interlingue',
        'ig' => 'Igbo',
        'ii' => 'Sichuan Yi',
        'ikt' => 'Kanlurang Canadian Inuktitut',
        'ilo' => 'Iloko',
        'inh' => 'Ingush',
        'io' => 'Ido',
        'is' => 'Icelandic',
        'it' => 'Italian',
        'iu' => 'Inuktitut',
        'ja' => 'Japanese',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jv' => 'Javanese',
        'ka' => 'Georgian',
        'kab' => 'Kabyle',
        'kac' => 'Kachin',
        'kaj' => 'Jju',
        'kam' => 'Kamba',
        'kbd' => 'Kabardian',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Kabuverdianu',
        'kfo' => 'Koro',
        'kg' => 'Kongo',
        'kgp' => 'Kaingang',
        'kha' => 'Khasi',
        'khq' => 'Koyra Chiini',
        'ki' => 'Kikuyu',
        'kj' => 'Kuanyama',
        'kk' => 'Kazakh',
        'kkj' => 'Kako',
        'kl' => 'Kalaallisut',
        'kln' => 'Kalenjin',
        'km' => 'Khmer',
        'kmb' => 'Kimbundu',
        'kn' => 'Kannada',
        'ko' => 'Korean',
        'koi' => 'Komi-Permyak',
        'kok' => 'Konkani',
        'kpe' => 'Kpelle',
        'kr' => 'Kanuri',
        'krc' => 'Karachay-Balkar',
        'krl' => 'Karelian',
        'kru' => 'Kurukh',
        'ks' => 'Kashmiri',
        'ksb' => 'Shambala',
        'ksf' => 'Bafia',
        'ksh' => 'Colognian',
        'ku' => 'Kurdish',
        'kum' => 'Kumyk',
        'kv' => 'Komi',
        'kw' => 'Cornish',
        'kwk' => 'Kwakʼwala',
        'ky' => 'Kirghiz',
        'la' => 'Latin',
        'lad' => 'Ladino',
        'lag' => 'Langi',
        'lb' => 'Luxembourgish',
        'lez' => 'Lezghian',
        'lg' => 'Ganda',
        'li' => 'Limburgish',
        'lil' => 'Lillooet',
        'lkt' => 'Lakota',
        'lmo' => 'Lombard',
        'ln' => 'Lingala',
        'lo' => 'Lao',
        'lou' => 'Louisiana Creole',
        'loz' => 'Lozi',
        'lrc' => 'Hilagang Luri',
        'lsm' => 'Saamia',
        'lt' => 'Lithuanian',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lun' => 'Lunda',
        'luo' => 'Luo',
        'lus' => 'Mizo',
        'luy' => 'Luyia',
        'lv' => 'Latvian',
        'mad' => 'Madurese',
        'mag' => 'Magahi',
        'mai' => 'Maithili',
        'mak' => 'Makasar',
        'mas' => 'Masai',
        'mdf' => 'Moksha',
        'men' => 'Mende',
        'mer' => 'Meru',
        'mfe' => 'Morisyen',
        'mg' => 'Malagasy',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta’',
        'mh' => 'Marshallese',
        'mi' => 'Māori',
        'mic' => 'Micmac',
        'min' => 'Minangkabau',
        'mk' => 'Macedonian',
        'ml' => 'Malayalam',
        'mn' => 'Mongolian',
        'mni' => 'Manipuri',
        'moe' => 'Innu-aimun',
        'moh' => 'Mohawk',
        'mos' => 'Mossi',
        'mr' => 'Marathi',
        'ms' => 'Malay',
        'mt' => 'Maltese',
        'mua' => 'Mundang',
        'mus' => 'Creek',
        'mwl' => 'Mirandese',
        'my' => 'Burmese',
        'myv' => 'Erzya',
        'mzn' => 'Mazanderani',
        'na' => 'Nauru',
        'nap' => 'Neapolitan',
        'naq' => 'Nama',
        'nb' => 'Norwegian Bokmål',
        'nd' => 'Hilagang Ndebele',
        'nds' => 'Low German',
        'ne' => 'Nepali',
        'new' => 'Newari',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niuean',
        'nl' => 'Dutch',
        'nmg' => 'Kwasio',
        'nn' => 'Norwegian Nynorsk',
        'nnh' => 'Ngiemboon',
        'no' => 'Norwegian',
        'nog' => 'Nogai',
        'nqo' => 'N’Ko',
        'nr' => 'South Ndebele',
        'nso' => 'Hilagang Sotho',
        'nus' => 'Nuer',
        'nv' => 'Navajo',
        'ny' => 'Nyanja',
        'nyn' => 'Nyankole',
        'oc' => 'Occitan',
        'ojb' => 'Hilagang-Kanluran ng Ojibwa',
        'ojc' => 'Central Ojibwa',
        'ojs' => 'Oji-Cree',
        'ojw' => 'Kanlurang Ojibwa',
        'oka' => 'Okanagan',
        'om' => 'Oromo',
        'or' => 'Odia',
        'os' => 'Ossetic',
        'pa' => 'Punjabi',
        'pag' => 'Pangasinan',
        'pam' => 'Pampanga',
        'pap' => 'Papiamento',
        'pau' => 'Palauan',
        'pcm' => 'Nigerian Pidgin',
        'pis' => 'Pijin',
        'pl' => 'Polish',
        'pqm' => 'Maliseet-Passamaquoddy',
        'prg' => 'Prussian',
        'ps' => 'Pashto',
        'pt' => 'Portuguese',
        'qu' => 'Quechua',
        'quc' => 'Kʼicheʼ',
        'rap' => 'Rapanui',
        'rar' => 'Rarotongan',
        'rhg' => 'Rohingya',
        'rm' => 'Romansh',
        'rn' => 'Rundi',
        'ro' => 'Romanian',
        'rof' => 'Rombo',
        'ru' => 'Russian',
        'rup' => 'Aromanian',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Rwa',
        'sa' => 'Sanskrit',
        'sad' => 'Sandawe',
        'sah' => 'Sakha',
        'saq' => 'Samburu',
        'sat' => 'Santali',
        'sba' => 'Ngambay',
        'sbp' => 'Sangu',
        'sc' => 'Sardinian',
        'scn' => 'Sicilian',
        'sco' => 'Scots',
        'sd' => 'Sindhi',
        'sdh' => 'Katimugang Kurdish',
        'se' => 'Hilagang Sami',
        'seh' => 'Sena',
        'ses' => 'Koyraboro Senni',
        'sg' => 'Sango',
        'sh' => 'Serbo-Croatian',
        'shi' => 'Tachelhit',
        'shn' => 'Shan',
        'si' => 'Sinhala',
        'sk' => 'Slovak',
        'sl' => 'Slovenian',
        'slh' => 'Katimugang Lushootseed',
        'sm' => 'Samoan',
        'sma' => 'Katimugang Sami',
        'smj' => 'Lule Sami',
        'smn' => 'Inari Sami',
        'sms' => 'Skolt Sami',
        'sn' => 'Shona',
        'snk' => 'Soninke',
        'so' => 'Somali',
        'sq' => 'Albanian',
        'sr' => 'Serbian',
        'srn' => 'Sranan Tongo',
        'ss' => 'Swati',
        'ssy' => 'Saho',
        'st' => 'Katimugang Sotho',
        'str' => 'Straits Salish',
        'su' => 'Sundanese',
        'suk' => 'Sukuma',
        'sv' => 'Swedish',
        'sw' => 'Swahili',
        'swb' => 'Comorian',
        'syr' => 'Syriac',
        'ta' => 'Tamil',
        'tce' => 'Katimugang Tutchone',
        'te' => 'Telugu',
        'tem' => 'Timne',
        'teo' => 'Teso',
        'tet' => 'Tetum',
        'tg' => 'Tajik',
        'tgx' => 'Tagish',
        'th' => 'Thai',
        'tht' => 'Tahltan',
        'ti' => 'Tigrinya',
        'tig' => 'Tigre',
        'tk' => 'Turkmen',
        'tl' => 'Tagalog',
        'tlh' => 'Klingon',
        'tli' => 'Tlingit',
        'tn' => 'Tswana',
        'to' => 'Tongan',
        'tok' => 'Toki Pona',
        'tpi' => 'Tok Pisin',
        'tr' => 'Turkish',
        'trv' => 'Taroko',
        'ts' => 'Tsonga',
        'tt' => 'Tatar',
        'ttm' => 'Northern Tutchone',
        'tum' => 'Tumbuka',
        'tvl' => 'Tuvalu',
        'tw' => 'Twi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahitian',
        'tyv' => 'Tuvinian',
        'tzm' => 'Central Atlas Tamazight',
        'udm' => 'Udmurt',
        'ug' => 'Uyghur',
        'uk' => 'Ukranian',
        'umb' => 'Umbundu',
        'ur' => 'Urdu',
        'uz' => 'Uzbek',
        'vai' => 'Vai',
        've' => 'Venda',
        'vi' => 'Vietnamese',
        'vo' => 'Volapük',
        'vun' => 'Vunjo',
        'wa' => 'Walloon',
        'wae' => 'Walser',
        'wal' => 'Wolaytta',
        'war' => 'Waray',
        'wbp' => 'Warlpiri',
        'wo' => 'Wolof',
        'wuu' => 'Wu Chinese',
        'xal' => 'Kalmyk',
        'xh' => 'Xhosa',
        'xog' => 'Soga',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Yiddish',
        'yo' => 'Yoruba',
        'yrl' => 'Nheengatu',
        'yue' => 'Cantonese',
        'zgh' => 'Standard Moroccan Tamazight',
        'zh' => 'Chinese',
        'zu' => 'Zulu',
        'zun' => 'Zuni',
        'zza' => 'Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Modernong Karaniwang Arabic',
        'de_CH' => 'Swiss High German',
        'en_GB' => 'Ingles na British',
        'en_US' => 'Ingles na American',
        'es_419' => 'Latin American na Espanyol',
        'es_ES' => 'European Spanish',
        'es_MX' => 'Mexican na Espanyol',
        'fa_AF' => 'Dari',
        'fr_CH' => 'Swiss na French',
        'nds_NL' => 'Low Saxon',
        'nl_BE' => 'Flemish',
        'pt_BR' => 'Portuges ng Brasil',
        'pt_PT' => 'European Portuguese',
        'ro_MD' => 'Moldavian',
        'sw_CD' => 'Congo Swahili',
        'zh_Hans' => 'Pinasimpleng Chinese',
        'zh_Hant' => 'Tradisyonal na Chinese',
    ],
];

==> symfony_8.0.3+dfsg.orig.tar.xz: symfony-8.0.3/src/Symfony/Component/Intl/Resources/data/languages/tl.php <==
<?php

return [
    'Names' => [
        'aa' => 'Afar',
        'ab' => 'Abkhazian',
        'ace' => 'Achinese',
        'ach' => 'Acoli',
        'ada' => 'Adangme',
        'ady' => 'Adyghe',
        'af' => 'Afrikaans',
        'agq' => 'Aghem',
        'ain' => 'Ainu',
        'ak' => 'Akan',
        'ale' => 'Aleut',
        'alt' => 'Southern Altai',
        'am' => 'Amharic',
        'an' => 'Aragonese',
        'ann' => 'Obolo',
        'anp' => 'Angika',
        'ar' => 'Arabic',
        'arn' => 'Mapuche',
        'arp' => 'Arapaho',
        'ars' => 'Najdi Arabic',
        'as' => 'Assamese',
        'asa' => 'Asu',
        'ast' => 'Asturian',
        'atj' => 'Atikamekw',
        'av' => 'Avaric',
        'awa' => 'Awadhi',
        'ay' => 'Aymara',
        'az' => 'Azerbaijani',
        'ba' => 'Bashkir',
        'bal' => 'Baluchi',
        'ban' => 'Balinese',
        'bas' => 'Basaa',
        'be' => 'Belarusian',
        'bem' => 'Bemba',
        'bez' => 'Bena',
        'bg' => 'Bulgarian',
        'bgc' => 'Haryanvi',
        'bgn' => 'Kanlurang Balochi',
        'bho' => 'Bhojpuri',
        'bi' => 'Bislama',
        'bin' => 'Bini',
        'bla' => 'Siksika',
        'blo' => 'Anii',
        'bm' => 'Bambara',
        'bn' => 'Bangla',
        'bo' => 'Tibetan',
        'br' => 'Breton',
        'brx' => 'Bodo',
        'bs' => 'Bosnian',
        'bug' => 'Buginese',
        'byn' => 'Blin',
        'ca' => 'Catalan',
        'cay' => 'Cayuga',
        'ccp' => 'Chakma',
        'ce' => 'Chechen',
        'ceb' => 'Cebuano',
        'cgg' => 'Chiga',
        'ch' => 'Chamorro',
        'chk' => 'Chuukese',
        'chm' => 'Mari',
        'cho' => 'Choctaw',
        'chp' => 'Chipewyan',
        'chr' => 'Cherokee',
        'chy' => 'Cheyenne',
        'ckb' => 'Central Kurdish',
        'clc' => 'Chilcotin',
        'co' => 'Corsican',
        'crg' => 'Michif',
        'crj' => 'Southern East Cree',
        'crk' => 'Plains Cree',
        'crl' => 'Northern East Cree',
        'crm' => 'Moose Cree',
        'crr' => 'Carolina Algonquian',
        'crs' => 'Seselwa Creole French',
        'cs' => 'Czech',
        'csw' => 'Swampy Cree',
        'cu' => 'Church Slavic',
        'cv' => 'Chuvash',
        'cy' => 'Welsh',
        'da' => 'Danish',
        'dak' => 'Dakota',
        'dar' => 'Dargwa',
        'dav' => 'Taita',
        'de' => 'German',
        'dgr' => 'Dogrib',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Lower Sorbian',
        'dua' => 'Duala',
        'dv' => 'Divehi',
        'dyo' => 'Jola-Fonyi',
        'dz' => 'Dzongkha',
        'dzg' => 'Dazaga',
        'ebu' => 'Embu',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'eka' => 'Ekajuk',
        'el' => 'Greek',
        'en' => 'Ingles',
        'eo' => 'Esperanto',
        'es' => 'Spanish',
        'et' => 'Estonian',
        'eu' => 'Basque',
        'ewo' => 'Ewondo',
        'fa' => 'Persian',
        'ff' => 'Fulah',
        'fi' => 'Finnish',
        'fil' => 'Filipino',
        'fj' => 'Fijian',
        'fo' => 'Faroese',
        'fon' => 'Fon',
        'fr' => 'French',
        'frc' => 'Cajun French',
        'frr' => 'Hilagang Frisian',
        'fur' => 'Friulian',
        'fy' => 'Western Frisian',
        'ga' => 'Irish',
        'gaa' => 'Ga',
        'gag' => 'Gagauz',
        'gd' => 'Scottish Gaelic',
        'gez' => 'Geez',
        'gil' => 'Gilbertese',
        'gl' => 'Galician',
        'gn' => 'Guarani',
        'gor' => 'Gorontalo',
        'gsw' => 'Swiss German',
        'gu' => 'Gujarati',
        'guz' => 'Gusii',
        'gv' => 'Manx',
        'gwi' => 'Gwichʼin',
        'ha' => 'Hausa',
        'hai' => 'Haida',
        'haw' => 'Hawaiian',
        'hax' => 'Katimugang Haida',
        'he' => 'Hebrew',
        'hi' => 'Hindi',
        'hil' => 'Hiligaynon',
        'hmn' => 'Hmong',
        'hr' => 'Croatian',
        'hsb' => 'Upper Sorbian',
        'ht' => 'Haitian',
        'hu' => 'Hungarian',
        'hup' => 'Hupa',
        'hur' => 'Halkomelem',
        'hy' => 'Armenian',
        'hz' => 'Herero',
        'ia' => 'Interlingua',
        'iba' => 'Iban',
        'ibb' => 'Ibibio',
        'id' => 'Indonesian',
        'ie' => 'Interlingue',
        'ig' => 'Igbo',
        'ii' => 'Sichuan Yi',
        'ikt' => 'Kanlurang Canadian Inuktitut',
        'ilo' => 'Iloko',
        'inh' => 'Ingush',
        'io' => 'Ido',
        'is' => 'Icelandic',
        'it' => 'Italian',
        'iu' => 'Inuktitut',
        'ja' => 'Japanese',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jv' => 'Javanese',
        'ka' => 'Georgian',
        'kab' => 'Kabyle',
        'kac' => 'Kachin',
        'kaj' => 'Jju',
        'kam' => 'Kamba',
        'kbd' => 'Kabardian',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Kabuverdianu',
        'kfo' => 'Koro',
        'kg' => 'Kongo',
        'kgp' => 'Kaingang',
        'kha' => 'Khasi',
        'khq' => 'Koyra Chiini',
        'ki' => 'Kikuyu',
        'kj' => 'Kuanyama',
        'kk' => 'Kazakh',
        'kkj' => 'Kako',
        'kl' => 'Kalaallisut',
        'kln' => 'Kalenjin',
        'km' => 'Khmer',
        'kmb' => 'Kimbundu',
        'kn' => 'Kannada',
        'ko' => 'Korean',
        'koi' => 'Komi-Permyak',
        'kok' => 'Konkani',
        'kpe' => 'Kpelle',
        'kr' => 'Kanuri',
        'krc' => 'Karachay-Balkar',
        'krl' => 'Karelian',
        'kru' => 'Kurukh',
        'ks' => 'Kashmiri',
        'ksb' => 'Shambala',
        'ksf' => 'Bafia',
        'ksh' => 'Colognian',
        'ku' => 'Kurdish',
        'kum' => 'Kumyk',
        'kv' => 'Komi',
        'kw' => 'Cornish',
        'kwk' => 'Kwakʼwala',
        'kxv' => 'Kuvi',
        'ky' => 'Kyrgyz',
        'la' => 'Latin',
        'lad' => 'Ladino',
        'lag' => 'Langi',
        'lb' => 'Luxembourgish',
        'lez' => 'Lezghian',
        'lg' => 'Ganda',
        'li' => 'Limburgish',
        'lij' => 'Ligurian',
        'lil' => 'Lillooet',
        'lkt' => 'Lakota',
        'lmo' => 'Lombard',
        'ln' => 'Lingala',
        'lo' => 'Lao',
        'lou' => 'Louisiana Creole',
        'loz' => 'Lozi',
        'lrc' => 'Hilagang Luri',
        'lsm' => 'Saamia',
        'lt' => 'Lithuanian',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lun' => 'Lunda',
        'luo' => 'Luo',
        'lus' => 'Mizo',
        'luy' => 'Luyia',
        'lv' => 'Latvian',
        'mad' => 'Madurese',
        'mag' => 'Magahi',
        'mai' => 'Maithili',
        'mak' => 'Makasar',
        'mas' => 'Masai',
        'mdf' => 'Moksha',
        'men' => 'Mende',
        'mer' => 'Meru',
        'mfe' => 'Morisyen',
        'mg' => 'Malagasy',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta’',
        'mh' => 'Marshallese',
        'mi' => 'Māori',
        'mic' => 'Micmac',
        'min' => 'Minangkabau',
        'mk' => 'Macedonian',
        'ml' => 'Malayalam',
        'mn' => 'Mongolian',
        'mni' => 'Manipuri',
        'moe' => 'Innu-aimun',
        'moh' => 'Mohawk',
        'mos' => 'Mossi',
        'mr' => 'Marathi',
        'ms' => 'Malay',
        'mt' => 'Maltese',
        'mua' => 'Mundang',
        'mus' => 'Creek',
        'mwl' => 'Mirandese',
        'my' => 'Burmese',
        'myv' => 'Erzya',
        'mzn' => 'Mazanderani',
        'na' => 'Nauru',
        'nap' => 'Neapolitan',
        'naq' => 'Nama',
        'nb' => 'Norwegian Bokmål',
        'nd' => 'Hilagang Ndebele',
        'nds' => 'Low German',
        'ne' => 'Nepali',
        'new' => 'Newari',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niuean',
        'nl' => 'Dutch',
        'nmg' => 'Kwasio',
        'nn' => 'Norwegian Nynorsk',
        'nnh' => 'Ngiemboon',
        'no' => 'Norwegian',
        'nog' => 'Nogai',
        'nqo' => 'N’Ko',
        'nr' => 'South Ndebele',
        'nso' => 'Hilagang Sotho',
        'nus' => 'Nuer',
        'nv' => 'Navajo',
        'ny' => 'Nyanja',
        'nyn' => 'Nyankole',
        'oc' => 'Occitan',
        'ojb' => 'Hilagang-Kanluran ng Ojibwa',
        'ojc' => 'Central Ojibwa',
        'ojs' => 'Oji-Cree',
        'ojw' => 'Kanlurang Ojibwa',
        'oka' => 'Okanagan',
        'om' => 'Oromo',
        'or' => 'Odia',
        'os' => 'Ossetic',
        'pa' => 'Punjabi',
        'pag' => 'Pangasinan',
        'pam' => 'Pampanga',
        'pap' => 'Papiamento',
        'pau' => 'Palauan',
        'pcm' => 'Nigerian Pidgin',
        'pis' => 'Pijin',
        'pl' => 'Polish',
        'pqm' => 'Maliseet-Passamaquoddy',
        'prg' => 'Prussian',
        'ps' => 'Pashto',
        'pt' => 'Portuguese',
        'qu' => 'Quechua',
        'quc' => 'Kʼicheʼ',
        'raj' => 'Rajasthani',
        'rap' => 'Rapanui',
        'rar' => 'Rarotongan',
        'rhg' => 'Rohingya',
        'rm' => 'Romansh',
        'rn' => 'Rundi',
        'ro' => 'Romanian',
        'rof' => 'Rombo',
        'ru' => 'Russian',
        'rup' => 'Aromanian',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Rwa',
        'sa' => 'Sanskrit',
        'sad' => 'Sandawe',
        'sah' => 'Yakut',
        'saq' => 'Samburu',
        'sat' => 'Santali',
        'sba' => 'Ngambay',
        'sbp' => 'Sangu',
        'sc' => 'Sardinian',
        'scn' => 'Sicilian',
        'sco' => 'Scots',
        'sd' => 'Sindhi',
        'sdh' => 'Katimugang Kurdish',
        'se' => 'Hilagang Sami',
        'seh' => 'Sena',
        'ses' => 'Koyraboro Senni',
        'sg' => 'Sango',
        'sh' => 'Serbo-Croatian',
        'shi' => 'Tachelhit',
        'shn' => 'Shan',
        'si' => 'Sinhala',
        'sk' => 'Slovak',
        'sl' => 'Slovenian',
        'slh' => 'Katimugang Lushootseed',
        'sm' => 'Samoan',
        'sma' => 'Katimugang Sami',
        'smj' => 'Lule Sami',
        'smn' => 'Inari Sami',
        'sms' => 'Skolt Sami',
        'sn' => 'Shona',
        'snk' => 'Soninke',
        'so' => 'Somali',
        'sq' => 'Albanian',
        'sr' => 'Serbian',
        'srn' => 'Sranan Tongo',
        'ss' => 'Swati',
        'ssy' => 'Saho',
        'st' => 'Katimugang Sotho',
        'str' => 'Straits Salish',
        'su' => 'Sundanese',
        'suk' => 'Sukuma',
        'sv' => 'Swedish',
        'sw' => 'Swahili',
        'swb' => 'Comorian',
        'syr' => 'Syriac',
        'szl' => 'Silesian',
        'ta' => 'Tamil',
        'tce' => 'Katimugang Tutchone',
        'te' => 'Telugu',
        'tem' => 'Timne',
        'teo' => 'Teso',
        'tet' => 'Tetum',
        'tg' => 'Tajik',
        'tgx' => 'Tagish',
        'th' => 'Thai',
        'tht' => 'Tahltan',
        'ti' => 'Tigrinya',
        'tig' => 'Tigre',
        'tk' => 'Turkmen',
        'tl' => 'Tagalog',
        'tlh' => 'Klingon',
        'tli' => 'Tlingit',
        'tn' => 'Tswana',
        'to' => 'Tongan',
        'tok' => 'Toki Pona',
        'tpi' => 'Tok Pisin',
        'tr' => 'Turkish',
        'trv' => 'Taroko',
        'ts' => 'Tsonga',
        'tt' => 'Tatar',
        'ttm' => 'Northern Tutchone',
        'tum' => 'Tumbuka',
        'tvl' => 'Tuvalu',
        'tw' => 'Twi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahitian',
        'tyv' => 'Tuvinian',
        'tzm' => 'Central Atlas Tamazight',
        'udm' => 'Udmurt',
        'ug' => 'Uyghur',
        'uk' => 'Ukrainian',
        'umb' => 'Umbundu',
        'ur' => 'Urdu',
        'uz' => 'Uzbek',
        'vai' => 'Vai',
        've' => 'Venda',
        'vec' => 'Venetian',
        'vi' => 'Vietnamese',
        'vmw' => 'Makhuwa',
        'vo' => 'Volapük',
        'vun' => 'Vunjo',
        'wa' => 'Walloon',
        'wae' => 'Walser',
        'wal' => 'Wolaytta',
        'war' => 'Waray',
        'wbp' => 'Warlpiri',
        'wo' => 'Wolof',
        'wuu' => 'Wu Chinese',
        'xal' => 'Kalmyk',
        'xh' => 'Xhosa',
        'xnr' => 'Kangri',
        'xog' => 'Soga',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Yiddish',
        'yo' => 'Yoruba',
        'yrl' => 'Nheengatu',
        'yue' => 'Cantonese',
        'za' => 'Zhuang',
        'zgh' => 'Standard Moroccan Tamazight',
        'zh' => 'Chinese',
        'zu' => 'Zulu',
        'zun' => 'Zuni',
        'zza' => 'Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Modern Standard Arabic',
        'en_US' => 'Ingles (American)',
        'es_419' => 'Latin American na Espanyol',
        'es_ES' => 'European Spanish',
        'es_MX' => 'Mexican na Espanyol',
        'fa_AF' => 'Dari',
        'nds_NL' => 'Low Saxon',
        'nl_BE' => 'Flemish',
        'pt_PT' => 'European Portuguese',
        'ro_MD' => 'Moldavian',
        'sw_CD' => 'Congo Swahili',
        'zh_Hans' => 'Pinasimpleng Chinese',
        'zh_Hant' => 'Tradisyonal na Chinese',
    ],
];
